@@ -2,8 +2,9 @@ package Log::Dispatch::Base;
 
 use strict;
 use warnings;
+use Scalar::Util qw( refaddr );
 
-our $VERSION = '2.53';
+our $VERSION = '2.57';
 
 sub _get_callbacks {
     shift;
@@ -45,6 +46,20 @@ sub add_callback {
     return;
 }
 
+sub remove_callback {
+    my $self = shift;
+    my $cb   = shift;
+
+    Carp::carp("given value $cb is not a valid callback")
+        unless ref $cb eq 'CODE';
+
+    my $cb_id = refaddr $cb;
+    $self->{callbacks}
+        = [ grep { refaddr $_ ne $cb_id } @{ $self->{callbacks} } ];
+
+    return;
+}
+
 1;
 
 # ABSTRACT: Code shared by dispatch and output objects.
@@ -53,13 +68,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Base - Code shared by dispatch and output objects.
 
 =head1 VERSION
 
-version 2.53
+version 2.57
 
 =head1 SYNOPSIS
 
@@ -76,6 +93,15 @@ does.
 
 =for Pod::Coverage add_callback
 
+=for Pod::Coverage remove_callback
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
