@@ -5,14 +5,17 @@ use warnings;
 
 use base qw( Log::Dispatch::File );
 
-our $VERSION = '2.53';
+our $VERSION = '2.57';
 
 use Fcntl qw(:DEFAULT :flock);
 
-sub _open_file {
+sub log_message {
     my $self = shift;
+    my %p    = @_;
 
-    $self->SUPER::_open_file();
+    if ( $self->{close} ) {
+        $self->_open_file;
+    }
 
     my $fh = $self->{fh};
 
@@ -22,15 +25,22 @@ sub _open_file {
     # just in case there was an append while we waited for the lock
     seek( $fh, 0, 2 )
         or die "Cannot seek to end of '$self->{filename}': $!";
-}
 
-sub log_message {
-    my $self = shift;
+    if ( $self->{syswrite} ) {
+        defined syswrite( $fh, $p{message} )
+            or die "Cannot write to '$self->{filename}': $!";
+    }
+    else {
+        print $fh $p{message}
+            or die "Cannot write to '$self->{filename}': $!";
+    }
 
-    $self->SUPER::log_message(@_);
-    return if $self->{close};
-
-    flock( $self->{fh}, LOCK_UN );
+    flock( $fh, LOCK_UN ) or die "Cannot unlock '$self->{filename}'";
+    if ( $self->{close} ) {
+        close $fh
+            or die "Cannot close '$self->{filename}': $!";
+        delete $self->{fh};
+    }
 }
 
 1;
@@ -41,13 +51,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::File::Locked - Subclass of Log::Dispatch::File to facilitate locking
 
 =head1 VERSION
 
-version 2.53
+version 2.57
 
 =head1 SYNOPSIS
 
@@ -81,6 +93,13 @@ another.
 
 L<perlfunc/flock>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
