@@ -3,28 +3,18 @@ package Log::Dispatch::Output;
 use strict;
 use warnings;
 
-our $VERSION = '2.53';
+our $VERSION = '2.57';
 
 use Log::Dispatch;
 
 use base qw( Log::Dispatch::Base );
 
+use Log::Dispatch::Vars qw( %LevelNamesToNumbers @OrderedLevels );
 use Params::Validate qw(validate SCALAR ARRAYREF CODEREF BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
 use Carp ();
 
-my $level_names
-    = [qw( debug info notice warning error critical alert emergency )];
-my $ln            = 0;
-my $level_numbers = {
-    ( map { $_ => $ln++ } @{$level_names} ),
-    warn  => 3,
-    err   => 4,
-    crit  => 5,
-    emerg => 7
-};
-
 sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
@@ -44,6 +34,7 @@ sub log {
 
     return unless $self->_should_log( $p{level} );
 
+    local $!;
     $p{message} = $self->_apply_callbacks(%p)
         if $self->{callbacks};
 
@@ -69,8 +60,8 @@ sub _basic_init {
         }
     );
 
-    $self->{level_names}   = $level_names;
-    $self->{level_numbers} = $level_numbers;
+    $self->{level_names}   = \@OrderedLevels;
+    $self->{level_numbers} = \%LevelNamesToNumbers;
 
     $self->{name} = $p{name} || $self->_unique_name();
 
@@ -182,13 +173,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Output - Base class for all Log::Dispatch::* objects
 
 =head1 VERSION
 
-version 2.53
+version 2.57
 
 =head1 SYNOPSIS
 
@@ -288,6 +281,10 @@ level then it will croak.
 Adds a callback (like those given during construction). It is added to the end
 of the list of callbacks.
 
+=head2 $dispatch->remove_callback( $code )
+
+Remove the given callback from the list of callbacks.
+
 =head1 SUBCLASSING
 
 This class should be used as the base class for all logging objects
@@ -300,6 +297,13 @@ set. Please make sure to use the C<_basic_init> method as described above.
 The actual logging implementation should be done in a C<log_message>
 method that you write. B<Do not override C<log>!>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
